function gen_fig2_fs1()
%GEN_FIG2_FS1 

colors = [94 208 255;
    255 247 69;
    204 35 65]./255;

load('psd_dat','m','e','freqs','labels');

for s = 1:length(m) % subjects
    
    % grid minor
    
    % make plots per individual bipolar pairs, to plot later
    
    fig('FontSize', 16, ...
        'Font', 'Arial', ...
        'border','on', ...
        'units', 'centimeters', ...
        'width',  6, ...
        'height', 6);
    
    ant = startsWith(labels{s},'B') | startsWith(labels{s},'AH');
    mid = startsWith(labels{s},'C') | startsWith(labels{s},'PH');
    post = startsWith(labels{s},'D'); % none really in the tail
    
    n_a = sum(ant);
    n_m = sum(mid);
    n_p = sum(post);
    
    cmap = cat(1, gen_shades(colors(1,:), n_a), ...
                  gen_shades(colors(2,:), n_m), ...);
                  gen_shades(colors(3,:), n_p));
    
    
    for c = 1:size(m{s},1)
        [l, p] = boundedline( freqs, squeeze(m{s}(c,:)), squeeze(e{s}(c,:)), ...
            'cmap', cmap(c,:));
        hold on
        
        
        for k = 1:length(l)
            set(l(k),'LineWidth',2)
            set(p(k),'FaceAlpha',.6);
        end
    end
    
    set(gca,'YScale', 'log', ...
        'box', 'off', ...
        'XLim', [1 20], ...
        'Xscale', 'log', ...
        'XTick', [1 2 4 9 20], ...
        'YTick', [10^-2 10^0 10^2 10^4], ...
        'YLim', [10^-2 10^4], ...
        'xgrid', 'on', ...
        'ygrid', 'on', ...
        'xminorgrid', 'off', ...
        'yminorgrid', 'off');
    
    xlabel('Frequency (Hz)');
    %         if e == 1
    ylabel('Power (\muV^2/Hz)');
    %         end
    
end

end


function [psd_dat, stats] = concat_psd(psd, do_stats)


for s = 1:length(psd)
    
    n_hc = sum(psd(s).h_idx);
    ps = nan(n_hc, size(psd(s).psd,2), 102);
    ap = ps;
    e_cnt = 1;
    for c = 1:size(psd(s).psd,1)
        
        if psd(s).h_idx(c)
            psd_dat = squeeze(nanmean(psd(s).psd(c,:,:),2));
            
            
            if do_stats
                for e = 1:size(psd(s).psd,2) % events
                    
                    freqs = psd(s).freqs;
                    dat = squeeze(log10(psd(s).psd(c,e,(freqs < 50 & freqs>0))));
                    
                    if any(isinf(dat))
                        continue
                    end
                    
                    spectra = fit_ps(freqs(freqs < 50 & freqs>0), ...
                        dat);
                    
                    ps(e_cnt,e,:) = spectra.ps_fit;
                    ap(e_cnt,e,:) = spectra.ap_fit;
                end
                e_cnt = e_cnt+1;
            end
            
        end
        
        % and now test (could also just return this as output, which would
        % enable across condition testing
    end
    if do_stats
        stats(s) = vartest_perm(ap, ps, freqs);
    else
        stats(s) = nan;
    end
    % fit spectra for each event, to test for significance of peaks, within
    % this condition
    
end

end

function stats = vartest_perm(ap, ps, freqs)
% nonparametric test comparing aperiodic fit to modeled ps with f-test (test
% of unequal variance as test statistic

ap = permute(ap, [2 1 3]);
ps = permute(ps, [2 1 3]);

cond1.powspctrm = ps;
cond1.dimord = 'rpt_chan_freq_time';
cond1.time   = 1;
cond1.freq   = freqs(freqs>0 & freqs < 50)';
for e = 1:size(ps, 2)
    cond1.label(e)  = {['c' num2str(e)]};
end

cond2.powspctrm = ap;
cond2.dimord = 'rpt_chan_freq_time';
cond2.time   = 1;
cond2.freq   = freqs(freqs>0 & freqs < 50)';

for e = 1:size(ap, 2)
    cond2.label(e)  = {['c' num2str(e)]};
end


correctm = 'cluster'; % cluster correction by default
numrandomization = 10000;
method = 'montecarlo';

cfg                  = [];
cfg.latency          = 'all';
cfg.parameter        = 'powspctrm';
cfg.method           = method;
cfg.statistic        = 'ft_statfun_vartest2';
cfg.channel          = 'all';
cfg.ivar             = 1;
cfg.frequency        = 'all';
cfg.design           = [ones(1,size(cond1.powspctrm,1)), ...
    ones(1,size(cond2.powspctrm,1))*2];
cfg.numrandomization = numrandomization;
cfg.alpha            = 0.05;

cfg.correctm         = correctm;
cfg.neighbours       = [];%neighbours;
cfg.clusterthreshold = 'nonparametric_individual';
cfg.correcttail      = 'none';
cfg.clusteralpha     = 0.05;
cfg.clusterstatistic = 'maxsum';

stats = ft_freqstatistics(cfg, cond1, cond2);


end

function colors = gen_shades(base_color, n)
% generates n colors (shades) around the base color

colors = [];
for i = 1:n
    colors(i,:) = (1-(i-1)*.2)*base_color;
end

end